-- cPanel mysql backup
GRANT USAGE ON *.* TO 'uuism'@'172.31.13.215' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'172.31.13.215';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'172.31.13.215';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'172.31.13.215';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'172.31.13.215';
GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'172.31.13.215';
GRANT USAGE ON *.* TO 'uuism'@'172.31.2.117' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
GRANT ALL PRIVILEGES ON `cptmpdb\_uuism\_MHMX4VxwNGzwGfz4`.* TO 'uuism'@'172.31.2.117';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'172.31.2.117';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'172.31.2.117';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'172.31.2.117';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'172.31.2.117';
GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'172.31.2.117';
GRANT USAGE ON *.* TO 'uuism'@'184.76.96.122' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'184.76.96.122';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'184.76.96.122';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'184.76.96.122';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'184.76.96.122';
GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'184.76.96.122';
GRANT USAGE ON *.* TO 'uuism'@'24.107.80.156' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'24.107.80.156';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'24.107.80.156';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'24.107.80.156';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'24.107.80.156';
GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'24.107.80.156';
GRANT USAGE ON *.* TO 'uuism'@'34.237.106.38' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
GRANT ALL PRIVILEGES ON `cptmpdb\_uuism\_MHMX4VxwNGzwGfz4`.* TO 'uuism'@'34.237.106.38';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'34.237.106.38';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'34.237.106.38';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'34.237.106.38';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'34.237.106.38';
GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'34.237.106.38';
GRANT USAGE ON *.* TO 'uuism'@'52.87.69.75' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'52.87.69.75';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'52.87.69.75';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'52.87.69.75';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'52.87.69.75';
GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'52.87.69.75';
GRANT USAGE ON *.* TO 'uuism'@'65.18.172.20' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'65.18.172.20';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'65.18.172.20';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'65.18.172.20';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'65.18.172.20';
GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'65.18.172.20';
GRANT USAGE ON *.* TO 'uuism'@'65.18.196.199' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'65.18.196.199';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'65.18.196.199';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'65.18.196.199';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'65.18.196.199';
GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'65.18.196.199';
GRANT USAGE ON *.* TO 'uuism'@'host2.uuserver.net' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'host2.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'host2.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'host2.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'host2.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'host2.uuserver.net';
GRANT USAGE ON *.* TO 'uuism'@'host3.uuserver.net' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'host3.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'host3.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'host3.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'host3.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'host3.uuserver.net';
GRANT USAGE ON *.* TO 'uuism'@'host4.uuserver.net' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
GRANT ALL PRIVILEGES ON `cptmpdb\_uuism\_MHMX4VxwNGzwGfz4`.* TO 'uuism'@'host4.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'host4.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'host4.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'host4.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'host4.uuserver.net';
GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'host4.uuserver.net';
GRANT USAGE ON *.* TO 'uuism'@'localhost' IDENTIFIED BY PASSWORD '*4DAF2F2129D8E11A627F7BBD9BB97CE832DFC325';
GRANT ALL PRIVILEGES ON `cptmpdb\_uuism\_MHMX4VxwNGzwGfz4`.* TO 'uuism'@'localhost';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism'@'localhost';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism'@'localhost';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism'@'localhost';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism'@'localhost';
GRANT ALL PRIVILEGES ON `uuism\_net\_wikidb`.* TO 'uuism'@'localhost';
GRANT USAGE ON *.* TO 'uuism_joom675'@'172.31.13.215' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'172.31.13.215';
GRANT USAGE ON *.* TO 'uuism_joom675'@'172.31.2.117' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'172.31.2.117';
GRANT USAGE ON *.* TO 'uuism_joom675'@'184.76.96.122' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'184.76.96.122';
GRANT USAGE ON *.* TO 'uuism_joom675'@'24.107.80.156' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'24.107.80.156';
GRANT USAGE ON *.* TO 'uuism_joom675'@'34.237.106.38' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'34.237.106.38';
GRANT USAGE ON *.* TO 'uuism_joom675'@'52.87.69.75' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'52.87.69.75';
GRANT USAGE ON *.* TO 'uuism_joom675'@'65.18.172.20' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'65.18.172.20';
GRANT USAGE ON *.* TO 'uuism_joom675'@'65.18.196.199' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'65.18.196.199';
GRANT USAGE ON *.* TO 'uuism_joom675'@'host2.uuserver.net' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'host2.uuserver.net';
GRANT USAGE ON *.* TO 'uuism_joom675'@'host3.uuserver.net' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'host3.uuserver.net';
GRANT USAGE ON *.* TO 'uuism_joom675'@'host4.uuserver.net' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'host4.uuserver.net';
GRANT USAGE ON *.* TO 'uuism_joom675'@'localhost' IDENTIFIED BY PASSWORD '*B49ECEEA6EC07EA63C406DBB47E66EF8CC6410A7';
GRANT ALL PRIVILEGES ON `uuism\_joom675`.* TO 'uuism_joom675'@'localhost';
GRANT USAGE ON *.* TO 'uuism_mw1980'@'172.31.13.215' IDENTIFIED BY PASSWORD '*A11E72E61BC912C4413A27D8000791E0429756C5';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism_mw1980'@'172.31.13.215';
GRANT USAGE ON *.* TO 'uuism_mw1980'@'172.31.2.117' IDENTIFIED BY PASSWORD '*A11E72E61BC912C4413A27D8000791E0429756C5';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism_mw1980'@'172.31.2.117';
GRANT USAGE ON *.* TO 'uuism_mw1980'@'184.76.96.122' IDENTIFIED BY PASSWORD '*A11E72E61BC912C4413A27D8000791E0429756C5';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism_mw1980'@'184.76.96.122';
GRANT USAGE ON *.* TO 'uuism_mw1980'@'24.107.80.156' IDENTIFIED BY PASSWORD '*A11E72E61BC912C4413A27D8000791E0429756C5';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism_mw1980'@'24.107.80.156';
GRANT USAGE ON *.* TO 'uuism_mw1980'@'34.237.106.38' IDENTIFIED BY PASSWORD '*A11E72E61BC912C4413A27D8000791E0429756C5';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism_mw1980'@'34.237.106.38';
GRANT USAGE ON *.* TO 'uuism_mw1980'@'52.87.69.75' IDENTIFIED BY PASSWORD '*A11E72E61BC912C4413A27D8000791E0429756C5';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism_mw1980'@'52.87.69.75';
GRANT USAGE ON *.* TO 'uuism_mw1980'@'65.18.172.20' IDENTIFIED BY PASSWORD '*A11E72E61BC912C4413A27D8000791E0429756C5';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism_mw1980'@'65.18.172.20';
GRANT USAGE ON *.* TO 'uuism_mw1980'@'65.18.196.199' IDENTIFIED BY PASSWORD '*A11E72E61BC912C4413A27D8000791E0429756C5';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism_mw1980'@'65.18.196.199';
GRANT USAGE ON *.* TO 'uuism_mw1980'@'host2.uuserver.net' IDENTIFIED BY PASSWORD '*A11E72E61BC912C4413A27D8000791E0429756C5';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism_mw1980'@'host2.uuserver.net';
GRANT USAGE ON *.* TO 'uuism_mw1980'@'host3.uuserver.net' IDENTIFIED BY PASSWORD '*A11E72E61BC912C4413A27D8000791E0429756C5';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism_mw1980'@'host3.uuserver.net';
GRANT USAGE ON *.* TO 'uuism_mw1980'@'host4.uuserver.net' IDENTIFIED BY PASSWORD '*A11E72E61BC912C4413A27D8000791E0429756C5';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism_mw1980'@'host4.uuserver.net';
GRANT USAGE ON *.* TO 'uuism_mw1980'@'localhost' IDENTIFIED BY PASSWORD '*A11E72E61BC912C4413A27D8000791E0429756C5';
GRANT ALL PRIVILEGES ON `uuism\_mw1980`.* TO 'uuism_mw1980'@'localhost';
GRANT USAGE ON *.* TO 'uuism_test'@'172.31.13.215' IDENTIFIED BY PASSWORD '*96C853ECE9869D8C8FB771448066D362F80EE399';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism_test'@'172.31.13.215';
GRANT USAGE ON *.* TO 'uuism_test'@'172.31.2.117' IDENTIFIED BY PASSWORD '*96C853ECE9869D8C8FB771448066D362F80EE399';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism_test'@'172.31.2.117';
GRANT USAGE ON *.* TO 'uuism_test'@'184.76.96.122' IDENTIFIED BY PASSWORD '*96C853ECE9869D8C8FB771448066D362F80EE399';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism_test'@'184.76.96.122';
GRANT USAGE ON *.* TO 'uuism_test'@'24.107.80.156' IDENTIFIED BY PASSWORD '*96C853ECE9869D8C8FB771448066D362F80EE399';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism_test'@'24.107.80.156';
GRANT USAGE ON *.* TO 'uuism_test'@'34.237.106.38' IDENTIFIED BY PASSWORD '*96C853ECE9869D8C8FB771448066D362F80EE399';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism_test'@'34.237.106.38';
GRANT USAGE ON *.* TO 'uuism_test'@'52.87.69.75' IDENTIFIED BY PASSWORD '*96C853ECE9869D8C8FB771448066D362F80EE399';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism_test'@'52.87.69.75';
GRANT USAGE ON *.* TO 'uuism_test'@'65.18.172.20' IDENTIFIED BY PASSWORD '*96C853ECE9869D8C8FB771448066D362F80EE399';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism_test'@'65.18.172.20';
GRANT USAGE ON *.* TO 'uuism_test'@'65.18.196.199' IDENTIFIED BY PASSWORD '*96C853ECE9869D8C8FB771448066D362F80EE399';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism_test'@'65.18.196.199';
GRANT USAGE ON *.* TO 'uuism_test'@'host2.uuserver.net' IDENTIFIED BY PASSWORD '*96C853ECE9869D8C8FB771448066D362F80EE399';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism_test'@'host2.uuserver.net';
GRANT USAGE ON *.* TO 'uuism_test'@'host3.uuserver.net' IDENTIFIED BY PASSWORD '*96C853ECE9869D8C8FB771448066D362F80EE399';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism_test'@'host3.uuserver.net';
GRANT USAGE ON *.* TO 'uuism_test'@'host4.uuserver.net' IDENTIFIED BY PASSWORD '*96C853ECE9869D8C8FB771448066D362F80EE399';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism_test'@'host4.uuserver.net';
GRANT USAGE ON *.* TO 'uuism_test'@'localhost' IDENTIFIED BY PASSWORD '*96C853ECE9869D8C8FB771448066D362F80EE399';
GRANT ALL PRIVILEGES ON `uuism\_test`.* TO 'uuism_test'@'localhost';
GRANT USAGE ON *.* TO 'uuism_whmcs'@'172.31.13.215' IDENTIFIED BY PASSWORD '*2BFD2AD51EF701554EB3A422744683A17FAF675D';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism_whmcs'@'172.31.13.215';
GRANT USAGE ON *.* TO 'uuism_whmcs'@'172.31.2.117' IDENTIFIED BY PASSWORD '*2BFD2AD51EF701554EB3A422744683A17FAF675D';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism_whmcs'@'172.31.2.117';
GRANT USAGE ON *.* TO 'uuism_whmcs'@'184.76.96.122' IDENTIFIED BY PASSWORD '*2BFD2AD51EF701554EB3A422744683A17FAF675D';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism_whmcs'@'184.76.96.122';
GRANT USAGE ON *.* TO 'uuism_whmcs'@'24.107.80.156' IDENTIFIED BY PASSWORD '*2BFD2AD51EF701554EB3A422744683A17FAF675D';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism_whmcs'@'24.107.80.156';
GRANT USAGE ON *.* TO 'uuism_whmcs'@'34.237.106.38' IDENTIFIED BY PASSWORD '*2BFD2AD51EF701554EB3A422744683A17FAF675D';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism_whmcs'@'34.237.106.38';
GRANT USAGE ON *.* TO 'uuism_whmcs'@'52.87.69.75' IDENTIFIED BY PASSWORD '*2BFD2AD51EF701554EB3A422744683A17FAF675D';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism_whmcs'@'52.87.69.75';
GRANT USAGE ON *.* TO 'uuism_whmcs'@'65.18.172.20' IDENTIFIED BY PASSWORD '*2BFD2AD51EF701554EB3A422744683A17FAF675D';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism_whmcs'@'65.18.172.20';
GRANT USAGE ON *.* TO 'uuism_whmcs'@'65.18.196.199' IDENTIFIED BY PASSWORD '*2BFD2AD51EF701554EB3A422744683A17FAF675D';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism_whmcs'@'65.18.196.199';
GRANT USAGE ON *.* TO 'uuism_whmcs'@'host2.uuserver.net' IDENTIFIED BY PASSWORD '*2BFD2AD51EF701554EB3A422744683A17FAF675D';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism_whmcs'@'host2.uuserver.net';
GRANT USAGE ON *.* TO 'uuism_whmcs'@'host3.uuserver.net' IDENTIFIED BY PASSWORD '*2BFD2AD51EF701554EB3A422744683A17FAF675D';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism_whmcs'@'host3.uuserver.net';
GRANT USAGE ON *.* TO 'uuism_whmcs'@'host4.uuserver.net' IDENTIFIED BY PASSWORD '*2BFD2AD51EF701554EB3A422744683A17FAF675D';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism_whmcs'@'host4.uuserver.net';
GRANT USAGE ON *.* TO 'uuism_whmcs'@'localhost' IDENTIFIED BY PASSWORD '*2BFD2AD51EF701554EB3A422744683A17FAF675D';
GRANT ALL PRIVILEGES ON `uuism\_whmcs`.* TO 'uuism_whmcs'@'localhost';
GRANT USAGE ON *.* TO 'uuismwiki'@'172.31.13.215' IDENTIFIED BY PASSWORD '*4B11623F105556C44488316BF682AB2A41AF5C7D';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `uuism\_net\_wikidb`.* TO 'uuismwiki'@'172.31.13.215';
GRANT USAGE ON *.* TO 'uuismwiki'@'172.31.2.117' IDENTIFIED BY PASSWORD '*4B11623F105556C44488316BF682AB2A41AF5C7D';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `uuism\_net\_wikidb`.* TO 'uuismwiki'@'172.31.2.117';
GRANT USAGE ON *.* TO 'uuismwiki'@'184.76.96.122' IDENTIFIED BY PASSWORD '*4B11623F105556C44488316BF682AB2A41AF5C7D';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `uuism\_net\_wikidb`.* TO 'uuismwiki'@'184.76.96.122';
GRANT USAGE ON *.* TO 'uuismwiki'@'24.107.80.156' IDENTIFIED BY PASSWORD '*4B11623F105556C44488316BF682AB2A41AF5C7D';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `uuism\_net\_wikidb`.* TO 'uuismwiki'@'24.107.80.156';
GRANT USAGE ON *.* TO 'uuismwiki'@'34.237.106.38' IDENTIFIED BY PASSWORD '*4B11623F105556C44488316BF682AB2A41AF5C7D';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `uuism\_net\_wikidb`.* TO 'uuismwiki'@'34.237.106.38';
GRANT USAGE ON *.* TO 'uuismwiki'@'52.87.69.75' IDENTIFIED BY PASSWORD '*4B11623F105556C44488316BF682AB2A41AF5C7D';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `uuism\_net\_wikidb`.* TO 'uuismwiki'@'52.87.69.75';
GRANT USAGE ON *.* TO 'uuismwiki'@'65.18.172.20' IDENTIFIED BY PASSWORD '*4B11623F105556C44488316BF682AB2A41AF5C7D';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `uuism\_net\_wikidb`.* TO 'uuismwiki'@'65.18.172.20';
GRANT USAGE ON *.* TO 'uuismwiki'@'65.18.196.199' IDENTIFIED BY PASSWORD '*4B11623F105556C44488316BF682AB2A41AF5C7D';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `uuism\_net\_wikidb`.* TO 'uuismwiki'@'65.18.196.199';
GRANT USAGE ON *.* TO 'uuismwiki'@'host2.uuserver.net' IDENTIFIED BY PASSWORD '*4B11623F105556C44488316BF682AB2A41AF5C7D';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `uuism\_net\_wikidb`.* TO 'uuismwiki'@'host2.uuserver.net';
GRANT USAGE ON *.* TO 'uuismwiki'@'host3.uuserver.net' IDENTIFIED BY PASSWORD '*4B11623F105556C44488316BF682AB2A41AF5C7D';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `uuism\_net\_wikidb`.* TO 'uuismwiki'@'host3.uuserver.net';
GRANT USAGE ON *.* TO 'uuismwiki'@'host4.uuserver.net' IDENTIFIED BY PASSWORD '*4B11623F105556C44488316BF682AB2A41AF5C7D';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `uuism\_net\_wikidb`.* TO 'uuismwiki'@'host4.uuserver.net';
GRANT USAGE ON *.* TO 'uuismwiki'@'localhost' IDENTIFIED BY PASSWORD '*4B11623F105556C44488316BF682AB2A41AF5C7D';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `uuism\_net\_wikidb`.* TO 'uuismwiki'@'localhost';
